==> median-viewer-3.6.0.tgz: package/webpack-dev.config.js <==
const path = require('path');
const webpack = require('webpack');
const UglifyJsPlugin = require('uglifyjs-webpack-plugin');

const API_URL = process.env.NODE_ENV !== "production"
  ? JSON.stringify('https://localhost:5000')
  : JSON.stringify("https://app.hellomedian.com");

const SOCKET_URL = process.env.NODE_ENV !== "production"
? JSON.stringify('https://localhost:3000')
: JSON.stringify("https://socket.hellomedian.com");

module.exports = {
  entry: './src/main.ts',
  output: {
    path: path.resolve(__dirname, './dist'),
    publicPath: '/dist/',
    filename: 'median-viewer.js'
  },
  module: {
    rules: [{
        test: /\.vue$/,
        loader: 'vue-loader',
        options: {
          loaders: {
            'scss': 'vue-style-loader!css-loader!sass-loader',
            'sass': 'vue-style-loader!css-loader!sass-loader?indentedSyntax',
          }
        }
      },
      {
        test: /\.tsx?$/,
        loader: 'ts-loader',
        exclude: /node_modules/,
        options: {
          appendTsSuffixTo: [/\.vue$/],
        }
      },
      {
        test: /\.(png|jpg|gif|svg)$/,
        loader: 'file-loader',
        options: {
          name: '[name].[ext]?[hash]'
        }
      }
    ]
  },
  resolve: {
    extensions: ['.ts', '.js', '.vue', '.json'],
    alias: {
      'vue$': 'vue/dist/vue.esm.js'
    }
  },
  devServer: {
    historyApiFallback: true,
    port: 9000,
    contentBase: __dirname + '/www'
  },
  performance: {
    hints: false
  },
  devtool: 'source-map-eval',
  plugins: [
    new webpack.LoaderOptionsPlugin({
      minimize: true
    }),
    // new UglifyJsPlugin({
    //   sourceMap: false,
    //   uglifyOptions: {
    //     mangle: true,
    //     compress: {
    //       pure_funcs: ['console.log']
    //     }
    //   }
    // }),
    new webpack.DefinePlugin({
      'process.env': {
        NODE_ENV: JSON.stringify(process.env.NODE_ENV),
        API_URL,
        SOCKET_URL
      }
    })
  ]
}


// plugins: [new UglifyJSPlugin({
//   sourceMap: false,
//   uglifyOptions: {
//     mangle: true,
//     compress: {
//       // Drop console log but keep error and warn
//       pure_funcs: ['console.log'],
//       warnings: false
//     },
//     output: {
//       comments: false,
//       beautify: false
//     }
//   }
// }),

==> median-viewer-3.9.0.tgz: package/webpack-dev.config.js <==
const path = require('path');
const webpack = require('webpack');
const UglifyJsPlugin = require('uglifyjs-webpack-plugin');

const API_URL = process.env.NODE_ENV !== "production"
  ? JSON.stringify('https://localhost:5000')
  : JSON.stringify("https://app.hellomedian.com");

const SOCKET_URL = process.env.NODE_ENV !== "production"
? JSON.stringify('https://localhost:3000')
: JSON.stringify("https://socket.hellomedian.com");

module.exports = {
  entry: './src/main.ts',
  output: {
    path: path.resolve(__dirname, './dist'),
    publicPath: '/dist/',
    filename: 'median-viewer.js'
  },
  module: {
    rules: [{
        test: /\.vue$/,
        loader: 'vue-loader',
        options: {
          loaders: {
            'scss': 'vue-style-loader!css-loader!sass-loader',
            'sass': 'vue-style-loader!css-loader!sass-loader?indentedSyntax',
          }
        }
      },
      {
        test: /\.tsx?$/,
        loader: 'ts-loader',
        exclude: /node_modules/,
        options: {
          appendTsSuffixTo: [/\.vue$/],
        }
      },
      {
        test: /\.(png|jpg|gif|svg)$/,
        loader: 'file-loader',
        options: {
          name: '[name].[ext]?[hash]'
        }
      }
    ]
  },
  resolve: {
    extensions: ['.ts', '.js', '.vue', '.json'],
    alias: {
      'vue$': 'vue/dist/vue.esm.js'
    }
  },
  devServer: {
    historyApiFallback: true,
    port: 9000,
    contentBase: __dirname + '/www'
  },
  performance: {
    hints: false
  },
  devtool: 'source-map',
  plugins: [
    // new UglifyJsPlugin({
    //   sourceMap: false,
    //   uglifyOptions: {
    //     mangle: true,
    //     compress: {
    //       pure_funcs: ['console.log']
    //     }
    //   }
    // }),
    new webpack.DefinePlugin({
      'process.env': {
        NODE_ENV: JSON.stringify(process.env.NODE_ENV),
        API_URL,
        SOCKET_URL
      }
    })
  ]
}


// plugins: [new UglifyJSPlugin({
//   sourceMap: false,
//   uglifyOptions: {
//     mangle: true,
//     compress: {
//       // Drop console log but keep error and warn
//       pure_funcs: ['console.log'],
//       warnings: false
//     },
//     output: {
//       comments: false,
//       beautify: false
//     }
//   }
// }),
